@@ -32,6 +32,7 @@ class Problem:
     startTime: Time = 0
     vehicleFixedCost: Cost = 0
     vehicleMaxTime: Time = maxsize
+    softVehicleMaxTime: Optional[Time] = None
     demands: Optional[list[Weight]] = None
     vehicleCapacities: Optional[list[Weight]] = None
 
@@ -49,6 +50,15 @@ class Problem:
         ] for i, row in enumerate(self.tripTimeTable)]
 
 
+    def averageTripTimeEstimate(self, numEffectiveVehicles = None):
+        if numEffectiveVehicles == None:
+            numEffectiveVehicles = self.numVehicles
+
+        tripTimeTable = self.properTripTimeTable()
+
+        return int(sum([sum(i) for i in tripTimeTable]) / len(tripTimeTable) / numEffectiveVehicles)
+
+
     @staticmethod
     def roundFloatTimeTable(tripTimeTable: list[list[float]]) -> TimeTable:
         return [[round(j) for j in i] for i in tripTimeTable]
